MainButtonParams class

Constructors

MainButtonParams({required String text, required String color, required String textColor, bool isVisible = true, bool isActive = false})

Properties

color ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isActive ↔ bool
getter/setter pair
isVisible ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair
textColor ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited