TelegramTheme class

Implement theme colors from telegram themeParams to flutter ThemeData

Constructors

TelegramTheme()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentTheme ThemeData?
no setter
dark ThemeData
no setter
light ThemeData
no setter
rawTheme ThemeData?
Raw themData from telegram themeParams This will return null if the theme is not supported (not telegram web)
no setter